@@ -42,10 +42,10 @@ print( coef( summary( wooldridge ) ), digits = 5 )
 print( coef( summary( wooldridge ), part = "outcome" ), digits = 5 )
 print( vcov( wooldridge ), digits = 5 )
 print( vcov( wooldridge, part = "outcome" ), digits = 5 )
-fitted( wooldridge, part = "outcome" )
-fitted( wooldridge, part = "selection" )
-residuals( wooldridge, part = "outcome" )
-residuals( wooldridge, part = "selection", type = "response" )
+round( fitted( wooldridge, part = "outcome" ), digits = 6 )
+round( fitted( wooldridge, part = "selection" ), digits = 6 )
+round( residuals( wooldridge, part = "outcome" ), digits = 6 )
+round( residuals( wooldridge, part = "selection", type = "response" ), digits = 6 )
 print( model.matrix( wooldridge, part = "outcome" ), digits = 5 )
 print( model.matrix( wooldridge, part = "selection" ), digits = 5 )
 print( model.frame( wooldridge ), digits = 5 )
